# Cease et al. 2015, The ins and outs of N and P through diet and waste management
# Appendix 3: R script for calculating waste-management patterns
# August 17, 2014

# Note that lines 10 and 165 require updating with user's directory path and filename

# Clear desktop & variables
rm (list=ls())
# Set working directory
setwd("[INSERT DIRECTORY PATH HERE]")

# Function to calculate the amount of N and P in human waste going to various fates
# Inputs: 
# diet = dataframe of excreta inputs
#    columns: DietPattern (name of diet pattern), ExcretaN, Excreta P (both in kg capita^-1 yr^-1_)
# waste = dataframe of waste-management parameters, named as in Table S2.1
#    note that all parameters must have values; can set unused parameters to zero

WasteModel<-function(diet,waste) {
  
  ### initial setup
  
  attach(waste)
  on.exit(detach(waste))
  
  DietPattern<-diet$DietPattern
  ExcretaN<-diet$ExcretaN
  ExcretaP<-diet$ExcretaP
  
  # Create output data frames; all values will be stored in one of these
  P<-data.frame(WastePattern=WastePattern) # Pollution
  S<-data.frame(WastePattern=WastePattern) # Storage
  R<-data.frame(WastePattern=WastePattern) # Recycling
  O<-data.frame(WastePattern=WastePattern) # Other (intermediates etc.)
  
  ### Calculating waste transformations
    
  ## Human Excreta
  # No sanitation, either direct reuse or direct discharge
  R$NoWWLandN<-ExcretaN*Prop_NoWW*NoWW_toLand
  R$NoWWLandP<-ExcretaP*Prop_NoWW*NoWW_toLand
  P$DirectDischargeN<-ExcretaN*Prop_NoWW*NoWW_toDischarge
  P$DirectDischargeP<-ExcretaP*Prop_NoWW*NoWW_toDischarge
  
  # Latrine
  O$LatrineN<-ExcretaN*Prop_Latrine
  O$LatrineP<-ExcretaP*Prop_Latrine
  
  # Septic
  O$SepticN<-ExcretaN*Prop_Septic
  O$SepticP<-ExcretaP*Prop_Septic
  
  ## Septic or Latrine outputs (combined) 
  # Solids
  O$SeptageN<-(O$SepticN*SepticN_toSeptage) + (O$LatrineN*LatrineN_toSeptage)
  O$SeptageP<-(O$SepticP*SepticP_toSeptage) + (O$LatrineP*LatrineP_toSeptage)
  # Septic/latrine solids disposal
  R$SeptageLandN<-O$SeptageN*Septage_toLand
  R$SeptageLandP<-O$SeptageP*Septage_toLand
  O$SeptageSewerN<-O$SeptageN*Septage_toSewer
  O$SeptageSewerP<-O$SeptageP*Septage_toSewer
  P$SeptageDischargeN<-O$SeptageN*Septage_toDischarge
  P$SeptageDischargeP<-O$SeptageP*Septage_toDischarge
  # Septic denitrification (advanced septic technologies)  
  S$SepticN2<-O$SepticN*SepticN_toN2
  # Septic or latrine effluent
  O$SepticEffluentN<-O$SepticN*SepticN_toEffluent + (O$LatrineN*LatrineN_toEffluent)
  O$SepticEffluentP<-O$SepticP*SepticP_toEffluent + (O$LatrineP*LatrineP_toEffluent)
  P$SepticEffluentN_toGW<-O$SepticEffluentN*SepticEffluentN_toGW
  P$SepticEffluentP_toGW<-O$SepticEffluentP*SepticEffluentP_toGW
  S$SepticSoilN<-O$SepticEffluentN*(1-SepticEffluentN_toGW) # to soil attenuation, incl. denit.
  S$SepticSoilP<-O$SepticEffluentP*(1-SepticEffluentP_toGW) 
  
  # Inputs to WWTP 
  O$SewerN<-(ExcretaN*Prop_Sewer)+O$SeptageSewerN
  O$SewerP<-(ExcretaP*Prop_Sewer)+O$SeptageSewerP
  # Wastewater treatment: solids, effluent, N2
  O$SewerSolidsN<-O$SewerN*SewerN_toSolids
  O$SewerSolidsP<-O$SewerP*SewerP_toSolids
  O$SewerEffluentN<-O$SewerN*SewerN_toEffluent
  O$SewerEffluentP<-O$SewerP*SewerP_toEffluent
  S$SewerN2<-O$SewerN*SewerN_toN2
  # WWTP Effluent disposal
  R$SewerEffluentReuseN<-O$SewerEffluentN*SewerEffluent_toReuse
  R$SewerEffluentReuseP<-O$SewerEffluentP*SewerEffluent_toReuse
  P$SewerEffluentDischargeN<-O$SewerEffluentN*SewerEffluent_toDischarge
  P$SewerEffluentDischargeP<-O$SewerEffluentP*SewerEffluent_toDischarge
  # WWTP Solids disposal
  S$SewerSolidsLandfillN<-O$SewerSolidsN*SewerSolids_toLandfill
  S$SewerSolidsLandfillP<-O$SewerSolidsP*(SewerSolids_toLandfill+SewerSolids_toIncinerator)
  S$SewerSolidsN2<-O$SewerSolidsN*SewerSolids_toIncinerator
  R$SewerSolidsLandN<-O$SewerSolidsN*SewerSolids_toLand
  R$SewerSolidsLandP<-O$SewerSolidsP*SewerSolids_toLand
  
  ### Totals and N:P ratios (by mass)
  P$TotalPollutionN<-P$DirectDischargeN +
                     P$SeptageDischargeN +
                     P$SepticEffluentN_toGW +
                     P$SewerEffluentDischargeN
  P$TotalPollutionP<-P$DirectDischargeP +
                     P$SeptageDischargeP +
                     P$SepticEffluentP_toGW +
                     P$SewerEffluentDischargeP
  
  # sum N2 from different sources
  S$N2<-S$SepticN2 +
    S$SewerN2 +
    S$SewerSolidsN2
  S$TotalStorageN<-S$N2 +
                   S$SewerSolidsLandfillN
  S$TotalStorageP<-S$SewerSolidsLandfillP +
                   S$SepticSoilP

  
  R$TotalRecyclingN<-
    R$NoWWLandN + 
    R$SeptageLandN +
    R$SewerEffluentReuseN +
    R$SewerSolidsLandN
  R$TotalRecyclingP<-
    R$NoWWLandP +
    R$SeptageLandP +
    R$SewerEffluentReuseP +
    R$SewerSolidsLandP  

 Summary<-data.frame(DietPattern=DietPattern,
                     WastePattern=WastePattern,
                     PollutionN=P$TotalPollutionN,
                     StorageN=S$TotalStorageN,
                     RecyclingN=R$TotalRecyclingN,
                     PollutionP=P$TotalPollutionP,
                     StorageP=S$TotalStorageP,
                     RecyclingP=R$TotalRecyclingP
 )
  
 Stoichiometry<-data.frame(WastePattern=WastePattern,
                           PollutionDischarge=(P$DirectDischargeN+P$SeptageDischargeN)/
                             (P$DirectDischargeP+P$SeptageDischargeP),
                           PollutionGW=P$SepticEffluentN_toGW/P$SepticEffluentP_toGW,
                           PollutionSurfaceWater=P$SewerEffluentDischargeN/
                             P$SewerEffluentDischargeP,
                           PollutionTotal=P$TotalPollutionN/P$TotalPollutionP,
                           StorageSoil=S$SepticSoilN/S$SepticSoilP,
                           RecycNoWW=R$NoWWLandN/R$NoWWLandP,
                           RecycSeptage=R$SeptageLandN/R$SeptageLandP,
                           RecycSewerEffluent=R$SewerEffluentReuseN/R$SewerEffluentReuseP,
                           RecycSewerSolids=R$SewerSolidsLandN/R$SewerSolidsLandP,
                           RecycTotal=R$TotalRecyclingN/R$TotalRecyclingP
 
   )

  ### Output list of all dataframes
  output<-list(Summary=Summary,
               Stoichiometry=Stoichiometry,
               Pollution=P,
               Storage=S,
               Recycling=R,
               Intermediates=O)
  output
  
} # End Function

### Example of using the function to calculate waste pattern outputs
# Read in csv file of waste patterns
WastePatterns<-read.csv("[INSERT NAME OF WASTE PATTERNS FILE].csv",header=T)

# Calculate proportion of N and P to different fates by
# entering "1" for both excreta N and P.
prop<-data.frame(DietPattern="Proportional",
                 ExcretaN=1,
                 ExcretaP=1
)
proportional<-WasteModel(diet=prop,waste=WastePatterns)
write.csv(proportional,"ProportionalWasteOutputs.csv")